@@ -125,12 +125,6 @@ override _build_config => sub
         sender  => 
         {
             mailer          => 'SMTP',
-            mailer_args     => 
-            {
-                host            => 'mail.opusvl.com',
-                username        => 'username',
-                password        => 'password',
-            }
         }
     };
 
@@ -190,7 +184,7 @@ OpusVL::AppKit::Builder
 
 =head1 VERSION
 
-version 2.20
+version 2.21
 
 =head1 SYNOPSIS
 
